##### printcolor

- Usage
```python
#pytho3.x
import printcolor
pc = printcolor.PrintColor()
pc.color(string,show="flash",front="green",back="yellow")
#pytho2.x
import printcolor
pc = printcolor.PrintColor()
pc.color("lash","green","yellow",string)
```
- color
```text
显示样式:
    hlt :  高亮
    underline : 下划线
    flash : 闪烁
字体/背景颜色：
    black : 黑色
    red:    红色
    green:  绿色
    yellow: 黄色
    blue:   蓝色
    carmine:胭脂红
    cyan:   青色
    white:  白色
```
```
- color
```text
显示样式:
    hlt :  高亮
    underline : 下划线
    flash : 闪烁
字体/背景颜色：
    black : 黑色
    red:    红色
    green:  绿色
    yellow: 黄色
    blue:   蓝色
    carmine:胭脂红
    cyan:   青色
    white:  白色
```
